# coding: utf-8
__author__ = 'mancuniancol'

import requests

import common
from bs4 import BeautifulSoup
from quasar import provider

# this read the settings
settings = common.Settings()
# create the filters
filters = common.Filtering()
# create the request session
browser = requests.Session()
browser.headers[
    'User-agent'] = 'Mozilla/5.0 (Windows NT 10.0; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/44.0.2403.157 Safari/537.36'
browser.headers['Accept-Language'] = 'en'


# using function from Steeve to add Provider's name and search torrent
def extract_torrents(data):
    try:
        filters.information()  # print filters settings
        soup = BeautifulSoup(data, 'html5lib')
        links = soup.select("div.browse-movie-bottom")
        cont = 0
        results = []
        for div in links:
            try:
                baseTitle = div.a.text  # title
                aList = div.select("div a")
                for a in aList:
                    name = baseTitle + ' ' + a.text
                    urlSource = a["href"]
                    infoHash = urlSource[urlSource.rfind("/") + 1:-8]
                    magnet = 'magnet:?xt=urn:btih:%s' % infoHash
                    if filters.verify(name, None):
                        cont += 1
                        results.append({"name": name.strip(),
                                        "uri": magnet,
                                        # "info_hash": info_magnet.hash,
                                        # "size": size.strip(),
                                        "language": settings.value.get("language", "en"),
                                        "provider": settings.name
                                        })  # return the torrent
                        if cont >= int(settings.value.get("max_magnets", 10)):  # limit magnets
                            break
                    else:
                        provider.log.warning(filters.reason)
            except:
                continue
        provider.log.info('>>>>>>' + str(cont) + ' torrents sent to Quasar<<<<<<<')
        return results
    except:
        provider.log.error('>>>>>>>ERROR parsing data<<<<<<<')
        provider.notify(message='ERROR parsing data', header=None, time=5000, image=settings.icon)
        return []


def search(query):
    return []


def search_general(info):
    info["extra"] = settings.value.get("extra", '')  # add the extra information
    query = filters.type_filtering(info, '%20')  # check type filter and set-up filters.title
    url_search = settings.value["url_address"]
    provider.log.info(url_search)
    # new code
    response = browser.get(url_search)
    soup = BeautifulSoup(response.text, 'html5lib')
    item_token = soup.select("div#mobile-search-input input")
    token = item_token[0]["value"]  # hidden token

    # Read
    provider.log.info(url_search)
    payload = {
        "keyword": query,
        "_token": token,
        "quality": "all",
        "genre": "all",
        "rating": "0",
        "order_by": "seeds",
    }
    provider.log.info(payload)
    response = browser.post(url_search + "/search-movies", data=payload)
    return extract_torrents(response.text)


def search_movie(info):
    info["type"] = "movie"
    if settings.value.get("language", "en") == "en":  # Title in english
        query = info['title'].encode('utf-8')  # convert from unicode
        if len(info['title']) != len(query):  # it is a english title
            query = common.IMDB_title(info['imdb_id'])  # Title + year
    else:  # Title en foreign language
        query = common.translator(info['imdb_id'], settings.value["language"])  # Just title
    info["query"] = query
    return search_general(info)


def search_episode(info):
    return []


# This registers your module for use
provider.register(search, search_movie, search_episode)

del settings
del browser
del filters
